@@ -5,7 +5,9 @@ alternative="two.sided", conf.level=0.95,
 
 {
 
-method<-match.arg(method, choices=c("Param.diff", "Param.ratio", "Lognorm.diff", "Lognorm.ratio","HL.diff", "HL.ratio", "HD.diff", "HD.ratio", "Median.diff" ,"Median.ratio", "Prop.diff", "Prop.diffAdd2", "Prop.ratio", "Prop.or"))
+
+method<-match.arg(method, choices=c("Param.diff", "Param.ratio", "Lognorm.diff", "Lognorm.ratio","HL.diff", "HL.ratio", "HD.diff", "HD.ratio", "Median.diff" ,"Median.ratio", "Prop.diff", "Prop.ratio", "Prop.or"))
+
 
 alternative<-match.arg(alternative, choices=c("two.sided", "less", "greater"))
 
@@ -23,6 +25,34 @@ if(length(formula[[3]]) != 1)
 if (all(class(data) != "data.frame"))
  {stop("argument data must be of class 'data.frame' ")}
 
+
+lhs<-formula[[2]]
+
+if(method %in% c("Prop.diff", "Prop.ratio", "Prop.or"))
+ {
+ if(as.character(formula[[2]])[1]!="cbind")
+  {stop("For methods for proportions please specify formula with structure: cbind(success, failure) ~ treatment")}
+
+ if(length(as.character(formula[[2]]))!=3)
+  {stop("For methods for proportions please specify formula with structure: cbind(success, failure) ~ treatment")}
+
+ clhs<-as.character(lhs)[c(2,3)]
+
+ if(!any(c(is.integer(data[[clhs[1]]]), is.numeric(data[[clhs[1]]]) )) )
+  {stop(paste("Response variable", clhs[1], "is not an integer variable"))}
+
+ if(!any(c(is.integer(data[[clhs[2]]]), is.numeric(data[[clhs[2]]]) )) )
+  {stop(paste("Response variable", clhs[2], "is not an integer variable"))}
+ 
+ }
+
+if(method %in% c("Param.diff","Param.ratio","Lognorm.diff","Lognorm.ratio", "HL.diff","HL.ratio","HD.diff", "HD.ratio", "Median.diff","Median.ratio"))
+ {
+ if(class(formula[[2]])[1]!="name")
+  {stop("For the specified method, please specify formula with structure: response ~ treatment")}
+ }
+
+
 # # #
 
 if(conf.level <= 0 || conf.level >= 1 || length(conf.level) > 1 || is.numeric(conf.level) == FALSE )
@@ -36,7 +66,7 @@ args$conf.level <- conf.level
 args$method <- method
 args$control <- control
 
-if(any(c("Prop.diff","Prop.diffAdd2", "Prop.or", "Prop.ratio")==method))
+if(any(c("Prop.diff", "Prop.or", "Prop.ratio")==method))
  {PWCINT<-"pairwiseCIProp"}
  else
  {PWCINT<-"pairwiseCICont"}
